==> nomachine-8.2.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUtmp.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUtmp;no warnings;($GLOBAL::WTMP_ENTRY="\x6e\x6f");sub add{if (((not (
defined ($GLOBAL::CommandSessreg)))or ($GLOBAL::CommandSessreg eq ("")))){
Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x1ea1+ 1675-0x252c));}(my $display=NXSessionParameters::getDisplay 
());(my $remoteip=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());(my $sessionType=
NXSessionParameters::getSessionType ());if (Common::NXSessionType::isUnixConsole
 ($sessionType)){Logger::debug (
"\x55\x6e\x69\x78\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x77\x69\x6c\x6c\x20\x68\x61\x6e\x64\x6c\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x67\x69\x73\x74\x65\x72\x2e"
);return ((0x0d4a+ 2720-0x17ea));}if ((not (-x ($GLOBAL::CommandSessreg)))){
Logger::debug ((("\x43\x61\x6e\x6e\x6f\x74\x20\x73\x74\x61\x74\x3a\x20".
$GLOBAL::CommandSessreg)."\x2e"));return ((0x0867+ 7807-0x26e6));}if ((not ((
$display=~ /^.{1,100}$/ )))){Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x06c3+ 5725-0x1d20));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0762+ 3855-0x1671));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x081a+ 6309-0x20bf));}Logger::debug ((((((
"\x4e\x58\x55\x74\x6d\x70\x3a".$display)."\x2c").$remoteip)."\x2c").$username));
(my (@command)=());push (@command,$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPADD
,$display,$remoteip,$username);(my (@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x69\x6e\x69\x73\x68\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}else{($GLOBAL::WTMP_ENTRY="\x79\x65\x73");}return (
(0x1f49+ 1462-0x24ff));}sub remove{if (((not (defined ($GLOBAL::CommandSessreg))
)or ($GLOBAL::CommandSessreg eq ("")))){Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x3a\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x0509+ 279-0x0620));}if (($GLOBAL::WTMP_ENTRY ne "\x79\x65\x73")){
Logger::debug (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x64\x69\x73\x61\x62\x6c\x65\x64");return (
(0x05c9+ 6816-0x2069));}(my $display=NXSessionParameters::getDisplay ());(my $remoteip
=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());if ((not (($display=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x00f3+ 7160-0x1ceb));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0bc2+ 6086-0x2388));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x12a8+ 3961-0x2221));}(my (@command)=());push (@command,
$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPDEL,$display,$remoteip,$username);(my (
@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x66\x69\x6e\x69\x73\x68\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}return ((0x157c+ 2438-0x1f02));}return ((0x1312+ 4961-0x2672));

==> nomachine-8.3.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUtmp.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXUtmp;no warnings;($GLOBAL::WTMP_ENTRY="\x6e\x6f");sub add{if (((not (
defined ($GLOBAL::CommandSessreg)))or ($GLOBAL::CommandSessreg eq ("")))){
Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x1734+ 1085-0x1b71));}(my $display=NXSessionParameters::getDisplay 
());(my $remoteip=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());(my $sessionType=
NXSessionParameters::getSessionType ());if (Common::NXSessionType::isUnixConsole
 ($sessionType)){Logger::debug (
"\x55\x6e\x69\x78\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x77\x69\x6c\x6c\x20\x68\x61\x6e\x64\x6c\x65\x20\x73\x65\x73\x73\x69\x6f\x6e\x20\x72\x65\x67\x69\x73\x74\x65\x72\x2e"
);return ((0x1b58+ 2313-0x2461));}if ((not (-x ($GLOBAL::CommandSessreg)))){
Logger::debug ((("\x43\x61\x6e\x6e\x6f\x74\x20\x73\x74\x61\x74\x3a\x20".
$GLOBAL::CommandSessreg)."\x2e"));return ((0x1a63+ 2211-0x2306));}if ((not ((
$display=~ /^.{1,100}$/ )))){Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x191b+ 365-0x1a88));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x01df+ 9465-0x26d8));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x079b+ 7167-0x239a));}Logger::debug ((((((
"\x4e\x58\x55\x74\x6d\x70\x3a".$display)."\x2c").$remoteip)."\x2c").$username));
(my (@command)=());push (@command,$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPADD
,$display,$remoteip,$username);(my (@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x69\x6e\x69\x73\x68\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}else{($GLOBAL::WTMP_ENTRY="\x79\x65\x73");}return (
(0x0993+ 5029-0x1d38));}sub remove{if (((not (defined ($GLOBAL::CommandSessreg))
)or ($GLOBAL::CommandSessreg eq ("")))){Logger::debug (
"\x4e\x58\x75\x74\x6d\x70\x3a\x20\x6c\x6f\x67\x67\x69\x6e\x67\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x140a+ 1989-0x1bcf));}if (($GLOBAL::WTMP_ENTRY ne "\x79\x65\x73")){
Logger::debug (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x64\x69\x73\x61\x62\x6c\x65\x64");return (
(0x13d4+ 2541-0x1dc1));}(my $display=NXSessionParameters::getDisplay ());(my $remoteip
=NXSessionParameters::getUserIp ());(my $username=
NXSessionParameters::getUsername ());if ((not (($display=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x72\x67\x75\x6d\x65\x6e\x74\x20\x64\x69\x73\x70\x6c\x61\x79\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x0acc+ 5570-0x208e));}if ((not (($remoteip=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x72\x65\x6d\x6f\x74\x65\x69\x70\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x1498+ 2531-0x1e7b));}if ((not (($username=~ /^.{1,100}$/ )))){
Logger::error (
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x20\x74\x6f\x6f\x20\x6c\x6f\x6e\x67\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x75\x70\x64\x61\x74\x65\x20\x77\x74\x6d\x70\x2f\x75\x74\x6d\x70\x20\x64\x62\x2e"
);return ((0x025d+ 4156-0x1299));}(my (@command)=());push (@command,
$GLOBAL::CommandNXexec,$GLOBAL::SCRIPT_WTMPDEL,$display,$remoteip,$username);(my (
@parameters)=());push (@parameters,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");(my (
$cmderr,$cmdout,$exit_code)=main::run_command ((\@command),(\@parameters)));if (
$exit_code){Logger::error ((
"\x4e\x58\x55\x74\x6d\x70\x3a\x20\x66\x69\x6e\x69\x73\x68\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x73\x3a\x20"
.$cmderr));}return ((0x1c9b+ 899-0x201e));}return ((0x0965+ 7582-0x2702));
